@@ -407,7 +407,7 @@ save_pseudonym_with_nick (struct PseuLookupContext *lctx, const char *nick)
   /* show the window */
   gtk_window_present (GTK_WINDOW (lctx->progress_dialog));
   memset (&rd, 0, sizeof (rd));
-  rd.data_size = GNUNET_IDENTITY_key_get_length (&lctx->pkey);
+  rd.data_size = GNUNET_IDENTITY_public_key_get_length (&lctx->pkey);
   rd.data = &lctx->pkey;
   rd.flags = GNUNET_GNSRECORD_RF_PRIVATE;
   rd.expiration_time = GNUNET_TIME_UNIT_FOREVER_ABS.abs_value_us;
