@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet
-     (C) 2005, 2006, 2010 Christian Grothoff (and other contributing authors)
+     Copyright (C) 2005, 2006, 2010 GNUnet e.V.
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -14,8 +14,8 @@
 
      You should have received a copy of the GNU General Public License
      along with GNUnet; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -35,8 +35,7 @@
  * @param toggle_menu name of menu entry
  */
 static void
-toggle_view (const char *toggled_widget,
-	     const char *toggle_menu)
+toggle_view (const char *toggled_widget, const char *toggle_menu)
 {
   GtkCheckMenuItem *mi;
   GtkWidget *widget;
@@ -61,11 +60,14 @@ check_extras ()
   GtkCheckMenuItem *m2;
   GtkWidget *wbox;
 
-  m1 = GTK_CHECK_MENU_ITEM (GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_main_menu_view_metadata"));
-  m2 = GTK_CHECK_MENU_ITEM (GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_main_menu_view_preview"));
-  wbox = GTK_WIDGET (GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_main_window_extras_vbox"));
-  if ( (gtk_check_menu_item_get_active (m1)) ||
-       (gtk_check_menu_item_get_active (m2)) )
+  m1 = GTK_CHECK_MENU_ITEM (GNUNET_FS_GTK_get_main_window_object (
+    "GNUNET_GTK_main_menu_view_metadata"));
+  m2 = GTK_CHECK_MENU_ITEM (
+    GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_main_menu_view_preview"));
+  wbox = GTK_WIDGET (GNUNET_FS_GTK_get_main_window_object (
+    "GNUNET_GTK_main_window_extras_vbox"));
+  if ((gtk_check_menu_item_get_active (m1)) ||
+      (gtk_check_menu_item_get_active (m2)))
     gtk_widget_show (wbox);
   else
     gtk_widget_hide (wbox);
@@ -79,8 +81,7 @@ check_extras ()
  * @param data main window builder (unused)
  */
 void
-GNUNET_GTK_main_menu_view_preview_toggled_cb (GtkWidget * dummy,
-					      gpointer data)
+GNUNET_GTK_main_menu_view_preview_toggled_cb (GtkWidget *dummy, gpointer data)
 {
   toggle_view ("GNUNET_GTK_main_window_preview_image",
                "GNUNET_GTK_main_menu_view_preview");
@@ -95,13 +96,11 @@ GNUNET_GTK_main_menu_view_preview_toggled_cb (GtkWidget * dummy,
  * @param data main window builder (unused)
  */
 void
-GNUNET_GTK_main_menu_view_metadata_toggled_cb (GtkWidget * dummy,
-					       gpointer data)
+GNUNET_GTK_main_menu_view_metadata_toggled_cb (GtkWidget *dummy, gpointer data)
 {
   toggle_view ("GNUNET_GTK_main_window_metadata_treeview",
                "GNUNET_GTK_main_menu_view_metadata");
   check_extras ();
-
 }
 
 
@@ -112,11 +111,11 @@ GNUNET_GTK_main_menu_view_metadata_toggled_cb (GtkWidget * dummy,
  * @param data main window builder (unused)
  */
 void
-GNUNET_GTK_main_menu_view_search_toggled_cb (GtkWidget * dummy,
-					     gpointer data)
+GNUNET_GTK_main_menu_view_search_toggled_cb (GtkWidget *dummy, gpointer data)
 {
   toggle_view ("main_window_search_hbox",
                "GNUNET_GTK_main_menu_search_preview");
 }
 
+
 /* end of gnunet-fs-gtk_main-window-view-toggles.c */
