@@ -212,12 +212,15 @@ GNUNET_GTK_display_about (const char *dialogfile)
     return;
   }
   ctx->about_credits_notebook = GTK_WIDGET (
-    gtk_builder_get_object (ctx->builder, "about_credits_notebook"));
+    gtk_builder_get_object (ctx->builder,
+                            "about_credits_notebook"));
   ctx->about_license_scroller = GTK_WIDGET (
     gtk_builder_get_object (ctx->builder, "about_license_scroller"));
-  ctx->ad = GTK_WIDGET (gtk_builder_get_object (ctx->builder, "about_window"));
+  ctx->ad = GTK_WIDGET (gtk_builder_get_object (ctx->builder,
+                                                "about_window"));
   ctx->license_contents =
-    GTK_TEXT_BUFFER (gtk_builder_get_object (ctx->builder, "license_contents"));
+    GTK_TEXT_BUFFER (gtk_builder_get_object (ctx->builder,
+                                             "license_contents"));
   gtk_widget_show (ctx->ad);
 }
 
